function get_lineparameters, imagename, image, graphics

; takes x,y image where x,y is space,lambda and square format 
; (use zeropad.pro if not) and returns 
; center, width, intensity and constant term of a gaussfit of 
; total spectrum.
;
; return array is of dimension 4 (center, width, intensity, offset)
; result is -1,-1,-1,-1 if no line region was specified

undersampling="no"	; set this to 'yes' if offset should not be fitted, no otherwise

dim=size(image)
; start and end pixel of spectral range (whole image)
a=0.
b=dim[2]*1.-1.

; read in parameters from file in datacubes/DATA
tmp = get_cube(imagename, "parameters")
lc=tmp[2]	; central wavelength in angstroem
disp=tmp[1]	; dispersion
a=tmp[3]	; start and ...
b=tmp[4]	; ...end pixel between line is found

parameters = fltarr(4)

if a ne -1 then begin
        c=(b-a)+1	; pixel range of line
       	tmp = total(image,1)
	spe=tmp[a:b]	; the spectral line
	lam=findgen(c)	; ...and its lambda values (in pixels)
	; gaussfit the line:
	if (undersampling  eq "yes") then begin
		print, "undersampling is yes"
		offset = min(spe)
		spe=spe-offset
		gfit = gaussfit(lam,spe, params, nterms=3)
		lcen=params[1]+a
		lwid=params[2]
		lint=params[0]
	endif else begin
        	gfit = gaussfit(lam,spe, params, nterms=4)
		lcen=params[1]+a
		lwid=params[2]
		lint=params[0]
		offset=params[3]
	endelse
	; put results in output array
	parameters(0) = lcen
	parameters(1) = lwid
	parameters(2) = lint
	parameters(3) = offset
	; make a plot if requested
        if graphics eq 1 then begin
		wset, 1
		g=lint*exp(-0.5*((lam+a-lcen)/lwid)^2) + offset
		pmin=min([spe,g]) & pmax=max([spe,g])
               	plot, spe, title="fit to get line parameters", yrange=[pmin,pmax]
        	oplot, g, line=3
		oplot, g, psym=4, symsize=2.
                legend,['profile','fit'], linestyle=[0,3]
	endif
endif else  parameters=[-1,-1,-1,-1]	; output if no spectral region was defined

return, parameters

end
