function iter_backprj, Niter, backprojection, image_fft, mask, fname, graphics,printflag, Ncurrent, Ns

; iteration to get rid of negatives in backprojection. 
; Niter			maximum number of iterations
; backprojection	input image in which to get rid of negatives
; image_fft		the fourier transform out of which backprojection was 
;			achieved
; mask			masks
; fname			name of file which will hold iteration step and totnegs
; graphics		flag for producing graphics
; printflag		flag for printing info for each step on screen
;			  if 1, only print info on last iteration
;			  if 2, print info on all iterations
; Ncurrent		current slice number
; Ns			the total number of slices
dimm=size(mask)
Nt=dimm[3]
Nx=dimm[1]
Ny=dimm[2]

;calculate total mask
mask_total = fltarr(Nx,Ny)
for t=0,Nt-1 do mask_total=mask_total+reform(mask[*,*,t])

;prepare graphics
if graphics eq 1 then begin
	window, 0, xpos=0, ypos=0, xsize=100, ysize=100
	wset, 0
endif

;prepare iteration
worst = min(backprojection)
totneg = total(backprojection<0)
;print,"min(backprojection) = ",worst
negs = backprojection<0
totnegs = total(negs)
;print,"total(backprojection<0) = ",totneg
counts = total(backprojection)
stats = sqrt(counts)
ssmask = where(mask_total)
lopass = where(dist(Nx,Ny) gt (Nx/2.0))
conv_x=0
conv_y=0

;open a file for convergence data
openw, 3, fname 

;iteration loop
for i=1L,Niter do begin
        backprojection = backprojection>0.0
        backfft = fft(backprojection)
        backfft[lopass] = 0.0
        backfft[ssmask] = image_fft[ssmask]
        backprojection = float(fft(backfft,/inverse))
        previous_totnegs = totnegs
        worst = min(backprojection)
        negs = backprojection<0
        totnegs = total(negs)
        conv_x=[conv_x,i]
        conv_y=[conv_y,totnegs]
        if (i/1 - i/1.0) eq 0 then begin
           if printflag ge 2 then $
		print,"slice ",strtrim(string(Ncurrent),2)," of ",$
		   strtrim(string(Ns),2)," iteration = ",$
		   strtrim(string(i),2)," min = ",worst," total<0 = ",totnegs
           printf, 3, i, totnegs
	   ;save, backprojection, file="pptmovie/movie"+strtrim(string(i),2)+".sav"
           if graphics eq 1 then begin
                wset,0
                tvscl,backprojection
           endif
        endif
        ;if abs(totnegs) lt stats/2.0 then break
endfor
conv_x=conv_x[1:N_ELEMENTS(conv_x)-1]
conv_y=conv_y[1:N_ELEMENTS(conv_y)-1]
lastniter = i
lasttotnegs = totnegs
if printflag ge 1 then $
	print,"iteration = ",i," min = ",worst," total<0 = ",totnegs
if graphics eq 1 then begin
        wset,0
        tvscl,backprojection
endif
;at this point, we'd return backprojection>0 as the result.
backprojection = backprojection > 0

;close file for convergence data
close, 3


return, backprojection


end
