function make_masks, theta, Nx

; input parameters: theta	array of angles (0 <= angle < 180)
;		    Nx		dimension of mask array. Masks are square	
;
; output: 	mask_t		3dim data cube with mask for each 
;				angle theta
;
; call: output = make_masks(theta, Nx)
;
; notes: only works properly when dimension Nx is an odd number!

Ny=Nx
Nt=N_ELEMENTS(theta)
tgst=tan(!PI*theta/180.)
mask_t = fltarr(Nx,Ny,Nt)
thetastr = "theta: "
for t=0,Nt-1 do begin
	thetastr = thetastr+strtrim(string(theta[t]),2)+" "
        case 1 of
	   (theta[t] eq 0): begin
		;print, strtrim(string(t),1),' make mask for angle t = ',theta[t]
		mask_t[0:Nx-1,Ny/2,t]=1.0
		end
	   (theta[t] eq 90): begin
                ;print, strtrim(string(t),1),' make mask for angle t = ',theta[t]
		mask_t[Nx/2,0:Ny-1,t]=1.0
		end
           (theta[t] eq  45): begin
                ;print, strtrim(string(t),1),' make mask for angle t = ',theta[t]
                for i=0,Nx-1 do begin
			mask_t[i,((Ny-i-1) mod Ny),t]=1.0
                endfor
                end
           (theta[t] eq -45): begin
                ;print, strtrim(string(t),1),' make mask for angle t = ',theta[t]
                for i=0,Nx-1 do begin
                        mask_t[i,i,t] = 1.0
                endfor
                end
           (theta[t] gt -45) and (theta[t] lt 45): begin
                ;print, strtrim(string(t),1),' make mask for angle t = ',theta[t]
		xi = indgen(Nx)
		yi = 0.5*(Ny-1)+0.5*(Nx-1)*tgst[t]-xi*tgst[t]+.5
		for i=0,N_ELEMENTS(xi)-1 do begin
			mask_t[xi[i],yi[i],t]=1.0
		endfor
                end
	   ((theta[t] gt  45) and (theta[t] lt  90)) or $
	   ((theta[t] gt -90) and (theta[t] lt -45)): begin
		;print, strtrim(string(t),1),' make mask for angle t = ',theta[t]
		yi = indgen(Ny)
		xi = 0.5*(Nx-1)+0.5*(Ny-1)/tgst[t]-yi/tgst[t]+.5
		for i=0,N_ELEMENTS(yi)-1 do begin
			mask_t[xi[i],yi[i],t] = 1.0
		endfor	
		end
           else: begin
                ;print, theta[t],' case not covered'
                end
        endcase
endfor
; origin in fourier domain should be lower left corner, so shift 
; the masks:
mask_t = shift(mask_t,-(Nx-1)/2,-(Ny-1)/2,0)
;print, 'masks done.'

return, mask_t

end
