@/usr/local/rsi/idl_5.5/lib/gaussfit.pro
pro mkgraphics, cubename, prefix

; restore structure created with 'prepgraphics'
filename=prefix+'results.sav'
restore, filename
; structure looks like this:
;result = {	   centhisto_orig:cent, 		widthhisto_orig:width, $
;                  centhisto_reconst:bcent, 		widthhisto_reconst:bwith, $
;                  centimage_orig:centim, 		widthimage_orig:widthim, $
;                  centimage_reconst:centbackim, 	widthimage_reconst:widthbackim, $
;                  centimagediff:diffc, 		widthimagediff:diffw, $
;                  intensityimage_orig:intim, 		intensityimage_reconst:intbackim, $
;                  centhisto_reconst_corr:bcentc, $
;                  centimage_reconst_corr:centbackimc, $
;                  centimagediff_corr:diffcc, $
;                  fwhm_center:fwhm_c, 			fwhm_center_kmps:fwhm_c_kmps, $
;                  fwhm_center_c:fwhm_cc, 		fwhm_center_c_kmps:fwhm_cc_kmps, $
;                  fwhm_width:fwhm_w, $
;                  aver_center:aver_c, 			aver_center_kmps:aver_c_kmps, $
;                  aver_center_c:aver_cc, 		aver_center_c_kmps:aver_cc_kmps, $
;                  aver_width:aver_w, $
;                  dispersion:disp, lambda0:lambda0}

; if mode = 'center', then print histogram only around +-3 fwhm
; if mode = 'all', print whole histogram (not implemented yet)
mode = 'center'

; calculate velocity tickmarks for line center histogram
transform = result.dispersion*200000./result.lambda0
if (mode eq 'all') then begin
	mincent=min(result.centhisto_orig)
	maxcent=max(result.centhisto_orig)
	velrange = (maxcent-mincent)*transform
endif else begin
	velrange = 6*result.fwhm_center_kmps
	mincent = result.aver_center_kmps-3*result.fwhm_center_kmps
endelse
a=abs(mincent)
if (a ne 0) then s=mincent/a else s=1
if (velrange le 200) then begin
	dv = velrange/10
	closest = s*(a+5-((a+5) mod 10))	; closest 10er to mincent
	dvticks = fix((indgen(dv)+closest/10))*10	; tickmarks every 10 km/s
endif else begin
	dv = velrange/100
	closest = s*(a+50-((a+50) mod 100))	; closest 100er to mincent
	dvticks = fix((indgen(dv)+closest/100))*100	; tickmarks every 100 km/s
endelse
dvan = strtrim(string(dvticks),2)	; used as annotation strings
i=where(dvan eq '0')
if (i ne -1) then dvan[i]=""
xdvticks = dvticks/transform		; the actual x position of annotation strings



; do some plots in ps 
; -------------------
; The following plots are done and are stored in the following files:
;
; HISTOGRAMS
; 1)  histogram for difference in line center			-> prefix+"centergraph2.eps"	and prefix+"centerhistogram.dat"
; 2)  histogram for difference in corrected line center		-> prefix+"centergraph2_c.eps"	and prefix+"centerhistogram_c.dat"
; 3)  histogram for difference in line width			-> prefix+"widthgraph2.eps"	and prefix+"widthhistogram.dat"
; IMAGES
; 4)  line center maps, original left and reconstr. right		-> prefix+"centergraph1.eps"
; 5)  corrected line center maps, original left and reconstr. right	-> prefix+"centergraph1_c.eps"
; 6)  line difference map						-> prefix+"centerdiff.eps"
; 7)  corrected line difference map					-> prefix+"centerdiff_c.eps"
; 8)  line width maps, original left and reconstr. right		-> prefix+"widthgraph1.eps"
; 9)  line width difference map						-> prefix+"widthdiff.eps"
; 10) plot an image of original and reconstr. cube at lambda for maximum intensity	-> prefix+"image.eps"

; prepare ps plots:
!p.charsize=1.5
!p.thick=3.
!p.charthick=2.
!x.style=1
!y.style=1
!p.position=[0.,0.,0.,0.5]
posvector=[0.25,0.2,0.9,0.85]	; position for plot
step=0.1	; bin size for histogram

; HISTOGRAMS

; 1) histogram for difference in line center
histc=histogram(result.centimagediff,binsize=step)
binc=findgen(n_elements(histc))*step+min(result.centimagediff)
set_plot, 'ps'
device, /encapsulated, filename=prefix+'centerhisto.eps', /color, /landscape
plot, binc,histc,psym=10,xstyle=8, pos=posvector, $
	xrange=[result.aver_center-3*result.fwhm_center,result.aver_center+3*result.fwhm_center], $
	xtitle='line center deviation in pixel'
axis, xaxis=1,xticks=n_elements(dvticks), xtickv=xdvticks, xtickn=dvan, $
	xtitle="line center deviation in km/s"
ac = 0.95*min(binc) & bc=0.9*max(histc)
;xyouts, ac,bc, "FWHM: "+strtrim(string(result.fwhm_center),2)+" pix"
;xyouts, ac,bc*.9, "       "+strtrim(string(result.fwhm_center_kmps),2)+" km/s"
!p.charsize=1.
legend,[prefix,'','FWHM:',strtrim(string(result.fwhm_center),2)+' pix',$
	strtrim(string(result.fwhm_center_kmps),2)+' km/s',$
	'','center:',strtrim(string(result.aver_center),2)+' pix',$
	strtrim(string(result.aver_center_kmps),2)+' km/s']
!p.charsize=1.5
device, /close
set_plot, 'x'
openw, 1, prefix+'centerhisto.dat'	; save histogram in file
	dim=size(binc)
	for i=0,dim[1]-1 do begin
		printf, 1, binc[i], histc[i]
	endfor
close, 1

; 2)  histogram for difference in corrected line center
histcc=histogram(result.centimagediff_corr,binsize=step)
bincc=findgen(n_elements(histcc))*step+min(result.centimagediff_corr)
set_plot, 'ps'
device, /encapsulated, filename=prefix+'centerhisto_corr.eps', /color, /landscape
plot, bincc,histcc,psym=10,xstyle=8, pos=posvector, $
	xrange=[result.aver_center_c-3*result.fwhm_center_c,result.aver_center_c+3*result.fwhm_center_c], $
	xtitle='corrected line center deviation in pixel'
axis, xaxis=1,xticks=n_elements(dvticks), xtickv=xdvticks, xtickn=dvan, $
	xtitle="corrected line center deviation in km/s"
acc=0.9*min(bincc) & bcc=0.9*max(histcc)
;xyouts, acc,bcc, "FWHM: "+strtrim(string(result.fwhm_center_c),2)
;xyouts, acc,bcc*.9, "       "+strtrim(string(result.fwhm_center_kmps),2)+" km/s"
!p.charsize=1.
legend,[prefix,'','FWHM:',strtrim(string(result.fwhm_center_c),2)+' pix',$
        strtrim(string(result.fwhm_center_c_kmps),2)+' km/s',$
        '','center:',strtrim(string(result.aver_center_c),2)+' pix',$
        strtrim(string(result.aver_center_c_kmps),2)+' km/s']
!p.charsize=1.5
device, /close
set_plot, 'x'
openw, 1, prefix+'centerhisto_corr.dat'  ; save histogram in file
        dim=size(bincc)
        for i=0,dim[1]-1 do begin
                printf, 1, bincc[i], histcc[i]
        endfor
close, 1

; 3)  histogram for difference in line width
histw=histogram(result.widthimagediff, binsize=step)
binw=findgen(n_elements(histw))*step+min(result.widthimagediff)
set_plot, 'ps'
device, /encapsulated, filename=prefix+'widthhisto.eps', /color, /landscape
plot, binw,histw,psym=10, pos=posvector, $
	xrange=[result.aver_width-3*result.fwhm_width,result.aver_width+3*result.fwhm_width], $
	xtitle="line width deviation in pixel"
aw=0.9*min(binw) & bw=0.9*max(histw)
;xyouts, aw,bw, "FWHM: "+strtrim(string(result.fwhm_width),2)
!p.charsize=1.
legend,[prefix,'','FWHM:',strtrim(string(result.fwhm_width),2)+' pix',$
        '','center:',strtrim(string(result.aver_width),2)+' pix']
!p.charsize=1.5
device, /close
set_plot, 'x'
openw, 1, prefix+'widthhisto.dat'   ; save in file
        dim=size(binw)
        for i=0,dim[1]-1 do begin
                printf, 1, binw[i], histw[i]
        endfor
close, 1

; do histogram plots quickly in x
!p.multi=[0,3,1]
plot, binc, histc, psym=10
xyouts, ac, bc, "fwhm = "+strtrim(string(result.fwhm_center),2)
plot, bincc, histcc, psym=10
xyouts, acc, bcc, "fwhm = "+strtrim(string(result.fwhm_center_c),2)
plot, binw, histw, psym=10
xyouts, aw, bw, "fwhm = "+strtrim(string(result.fwhm_width),2)
!p.multi=[0,1,1]


; IMAGES

; 4)  line center maps, original left and reconstr. right
load_vel
set_plot, 'ps'
device, /encapsulated, filename=prefix+'centermap.eps', /color, /landscape
!p.charsize=1.5
; convert pixels into radial velocities
velmap_orig = result.centimage_orig*result.dispersion*300000./result.lambda0
velmap_reconst = result.centimage_reconst*result.dispersion*300000./result.lambda0
; get indices of those where vrad is defined and form average over them
i = where(velmap_orig ne 0) 		; get indices of those where vrad is defined...
if (total(i) ne -1) then m1=moment(velmap_orig[i]) else m1=moment(velmap_orig)		; ...and take average over them
i = where(velmap_orig eq 0)		; get indices of those where vrad is not defined
velmap_orig = velmap_orig-m1[0] 	; shift so that average value is 0
if (total(i) ne -1) then velmap_orig[i]=0. 	; set vrad to zero where vrad is not defined
i=where(velmap_reconst eq 0)		; get indices of the reconstructed vrad which are not defined
velmap_reconst = velmap_reconst-m1[0]	; shift to same average as original
if (total(i) ne -1) then velmap_reconst[i]=0. ; set undefined vrad to zero
mini=-3*sqrt(m1[1])
maxi=3*sqrt(m1[1])
tmp=size(result.centimage_orig)
if tmp[1] le tmp[2] then begin
   ; portrait plot
   !p.multi=[0,1,2]
   plot_image, position=[.2,.2,.45,.9], velmap_orig, min=mini, max=maxi,$
	title='original', /velocity
   plot_image, position=[.65,.2,.9,.9], velmap_reconst, min=mini, max=maxi, $
	title='reconstructed', /velocity
   color_bar, [mini,maxi], .54,.57,.2,.9, /norm, /velocity, title="km/s"
   !p.multi=[0,1,1]
endif else begin
   ; landscape plot
   !p.multi=[0,2,1]
   plot_image, position=[.2,.65,.9,.9], velmap_orig, $
        title='original', /velocity
   plot_image, position=[.2,.2,.9,.45], velmap_reconst, $
        title='reconstructed', /velocity
   color_bar, [mini,maxi], .2,.9,.56,.59, /norm, /velocity, title="km/s"
   !p.multi=[0,1,1]
endelse
device, /close
set_plot, 'x'

; 5)  corrected line center maps, original left and reconstr. right
set_plot, 'ps'
device, /encapsulated, filename=prefix+'centermap_corr.eps', /color, /landscape
;!p.multi=[0,2,1]
!p.charsize=1.5
; convert pixels into radial velocities
velmap_orig = result.centimage_orig*result.dispersion*300000./result.lambda0
velmap_reconst = result.centimage_reconst_corr*result.dispersion*300000./result.lambda0
; get indices of those where vrad is defined and form average over them
i = where(velmap_orig ne 0)             ; get indices of those where vrad is defined...
if (total(i) ne -1) then m1=moment(velmap_orig[i]) else m1=moment(velmap_orig)              ; ...and take average over them
i = where(velmap_orig eq 0)             ; get indices of those where vrad is not defined
velmap_orig = velmap_orig-m1[0]         ; shift so that average value is 0
if (total(i) ne -1) then velmap_orig[i]=0.  ; set vrad to zero where vrad is not defined
i=where(velmap_reconst eq 0)            ; get indices of the reconstructed vrad which are not defined
velmap_reconst = velmap_reconst-m1[0]   ; shift to same average as original
if (total(i) ne -1) then velmap_reconst[i]=0.  ; set undefined vrad to zero
mini=-3*sqrt(m1[1])
maxi=3*sqrt(m1[1])
tmp=size(result.centimage_orig)
if tmp[1] le tmp[2] then begin
   !p.multi=[0,1,2]
   plot_image, position=[.2,.2,.45,.9], velmap_orig, $
        title='original', /velocity
   plot_image, position=[.65,.2,.9,.9], velmap_reconst, $
        title='reconstructed', /velocity
   color_bar, [mini,maxi], .54,.57,.2,.9, /norm, /velocity
   !p.multi=[0,1,1]
endif else begin
   !p.multi=[0,2,1]
   plot_image, position=[.2,.65,.9,.9], velmap_orig, $
        title='original', /velocity
   plot_image, position=[.2,.2,.9,.45], velmap_reconst, $
        title='reconstructed', /velocity
   color_bar, [mini,maxi], .2,.9,.56,.59, /norm, /velocity
   !p.multi=[0,1,1]
endelse
!p.multi=[0,1,1]
device, /close
set_plot, 'x'

; 6)  line difference map
centerdiff = result.centimage_reconst-result.centimage_orig
veldiff = centerdiff*result.dispersion*300000./result.lambda0
load_vel
!p.charsize=1.5
set_plot, 'ps'
device, /encapsulated, filename=prefix+'centerdiffmap.eps', /color, /landscape
tmp=size(veldiff)
if tmp[1] le tmp[2] then begin
   ; portrait arrays
   plot_image, position=[.45,.2,.7,.9], veldiff, /velocity, $
	title="line center difference"
   color_bar, veldiff, .3,.33,.2,.9, /norm, /velocity, title="km/s"
endif else begin
   ; landscape arrays
   plot_image, position=[.2,.4,.9,.65], veldiff, /velocity, $
	title="line center difference"
   color_bar, veldiff, .2,.9,.17,.2, /norm, /velocity, title="km/s"
endelse
device, /close
set_plot, 'x'

; 7)  corrected line difference map
centerdiffc = result.centimage_reconst_corr-result.centimage_orig
veldiffc = centerdiffc*result.dispersion*300000./result.lambda0
load_vel
!p.charsize=1.5
set_plot, 'ps'
device, /encapsulated, filename=prefix+'centerdiffmap_c.eps', /color, /landscape
tmp=size(veldiffc)
if tmp[1] le tmp[2] then begin
   ; portrait arrays
   plot_image, position=[.45,.2,.7,.9], veldiffc, /velocity, $
        title="corr. line center difference"
   color_bar, veldiffc, .3,.33,.2,.9, /norm, /velocity, title="km/s"
endif else begin
   ; landscape arrays
   plot_image, position=[.2,.4,.9,.65], veldiffc, /velocity, $
        title="corr. line center difference"
   color_bar, veldiffc, .2,.9,.17,.2, /norm, /velocity, title="km/s"
endelse
device, /close
set_plot, 'x'


; 8)  line width maps, original left and reconstr. right
set_plot, 'ps'
device, /encapsulated, filename=prefix+'widthmap.eps', /color, /landscape
!p.multi=[0,2,1]
!p.charsize=1.5
loadct, 2
mini=min([result.widthimage_orig,result.widthimage_reconst]) 
maxi=max([result.widthimage_orig,result.widthimage_reconst])
tmp=size(result.widthimage_orig)
if tmp[1] le tmp[2] then begin
   !p.multi=[0,1,2]
   plot_image, position=[.2,.2,.45,.9], result.widthimage_orig, min=mini, max=maxi, $
        title='original'
   plot_image, position=[.65,.2,.9,.9], result.widthimage_reconst, min=mini,max=maxi, $
        title='reconstructed'
   color_bar, [mini,maxi], .54,.57,.2,.9, /norm
   !p.multi=[0,1,1]
endif else begin
   !p.multi=[0,2,1]
   plot_image, position=[.2,.65,.9,.9], result.widthimage_orig, min=mini, max=maxi, $
        title='original'
   plot_image, position=[.2,.2,.9,.45], result.widthimage_reconst, min=mini,max=maxi, $
        title='reconstructed'
   color_bar, [mini,maxi], .2,.9,.56,.59, /norm
   !p.multi=[0,1,1]
endelse
!p.multi=[0,1,1]
device, /close
set_plot, 'x'

; 9) line width difference map
widthdiff = result.widthimage_reconst-result.widthimage_orig
load_vel
!p.charsize=1.5
set_plot, 'ps'
device, /encapsulated, filename=prefix+'widthdiffmap.eps', /color, /landscape
tmp=size(widthdiff)
if tmp[1] le tmp[2] then begin
   plot_image, position=[.45,.2,.7,.9], widthdiff, /velocity, $
        title="line width difference"
   color_bar, veldiff, .3,.33,.2,.9, /norm, /velocity, title="pixel"
endif else begin
   plot_image, position=[.2,.4,.9,.65], widthdiff, /velocity, $
        title="line width difference"
   color_bar, widthdiff, .2,.9,.17,.2, /norm, /velocity, title="pixel"
endelse
device, /close
set_plot, 'x'


; 10)  plot an image of original and reconstr. cube at lambda for maximum intensity
; restore cube
restore, prefix+"cube.sav"
restore, prefix+"backcube.sav"
; get lambda pixel for maximum intensity
tmp=moment(result.centhisto_orig)
lambdamax=round(tmp[0])
tmp=moment(result.centhisto_reconst)
lambdabackmax=round(tmp[0])
; get image for that lambda point
intimage = reform(cube[lambdamax,*,*])
intbackimage=reform(backcube[lambdabackmax,*,*])
!p.charsize=1.5
!p.thick=3.
!p.charthick=2.
!x.style=1
!y.style=1
loadct, 3
set_plot, 'ps'
device, /encapsulated, filename=prefix+'image.eps', /color, /landscape
mini=min([intimage,intbackimage]) & maxi=max([intimage,intbackimage])
tmp=size(intimage)
if tmp[1] le tmp[2] then begin
   !p.multi=[0,1,2]
   plot_image, position=[.2,.2,.45,.9], intimage, min=mini, max=maxi, $
        title='original'
   plot_image, position=[.65,.2,.9,.9], intbackimage, min=mini,max=maxi, $
        title='reconstructed'
   color_bar, [mini,maxi], .54,.57,.2,.9, /norm
endif else begin
   !p.multi=[0,2,1]
   plot_image, position=[.2,.65,.9,.9], intimage, min=mini, max=maxi, $
        title='original'
   plot_image, position=[.2,.2,.9,.45], intbackimage, min=mini,max=maxi, $
        title='reconstructed'
   color_bar, [mini,maxi], .2,.9,.56,.59, /norm
endelse
!p.multi=[0,1,1]
device, /close
set_plot, 'x'

; reset graphics
!p.charsize=1.
!p.thick=1.


end
