pro parametertrend, prefix
;
; produces plots which show systematic deviation of reconstructed line parameters 
; from true line parameters.
;
; prerequisites:
; 'sim_deconv' was run, from which is needed 
;	prefix+"lineparameters_av.dat"
;	(average line parameters for each image slice of the cube)
; 'widthcenter' was run then, from which is needed here:
;	prefix+"lineparameters.dat"
;	prefix+"lineparameters_c.dat"
;	(line parameters of each profile, raw and corrected)
;
; to following plots are produced:
;	prefix+'trend.eps'	plot for line center errors
;	prefix+'trend_c.eps'	plot for corrected line center errors (ideally horizontal line)
;	prefix+'trendw.eps'	plot for line width errors


; read in line parameters for average profiles
;; count number of slices/elements
openr, 1, prefix+"lineparameters_av.dat"
string=""
n=0
while not eof(1) do begin
	readf, 1, string
	n=n+1
endwhile
close, 1

; read in into arrays
sl=fltarr(n)
p1=fltarr(n)
p2=fltarr(n)
lc=fltarr(n)
lw=fltarr(n)

openr, 1, prefix+"lineparameters_av.dat"
i=0
while not eof(1) do begin
	readf, 1, x1,x2,x3,x4,x5
	sl[i] = x1		; slice number	
	p1[i] = x2		; padd_1
	p2[i] = x3		; padd_2
	lc[i] = x4-x2		; average line center of slice 
	lw[i] = x5		; average line width of slice
	i=i+1
endwhile
close, 1


; read in line parameters
nn=(n+1L)*(n+1L+x2+x3)
x=fltarr(nn)+99999.
y=fltarr(nn)+99999.
xw=fltarr(nn)+99999.
yw=fltarr(nn)+99999.
openr, 2, prefix+"lineparameters.dat"
k=0L
while not eof(2) do begin
	readf, 2, i,j,lcen,lwid,blcen,blwid
	index=where(sl eq j)
	y[k] = blcen-lcen
	x[k] = lcen-lc[index]
	yw[k]= blwid-lwid
	xw[k]= lwid-lw[index]
	k=k+1
endwhile
close, 2

; read in line parameters from corrected data
xc=fltarr(nn)+99999.
yc=fltarr(nn)+99999.
openr, 2, prefix+"lineparameters_c.dat"
k=0L
while not eof(2) do begin
        readf, 2, i,j,lcen,lwid,blcen,blwid
        index=where(sl eq j)
        yc[k] = blcen-lcen
        xc[k] = lcen-lc[index]
        k=k+1
endwhile
close, 2


index = where(x ne 99999.)
xx=x[index]
yy=y[index]
xxc=xc[index]
yyc=yc[index]
xxw=xw[index]
yyw=yw[index]

; do linear fits
a=-3
b=3
lfit = linfit(xx,yy)
yl1=lfit[0]+a*lfit[1]
yl2=lfit[0]+b*lfit[1]
lfitc = linfit(xxc,yyc)
ylc1=lfitc[0]+a*lfitc[1]
ylc2=lfitc[0]+b*lfitc[1]


; plots for x
; fit results go in logfile
openu, 1, 'LOGFILE', /append
!p.thick=1.
!x.style=1
!y.style=1
!p.multi=[0,2,1]
plot, xx, yy, psym=3, $
	xtitle="true - average line center", $
	ytitle="reconstr. - true line center", $
	xrange=[a,b], yrange=[a,b]
print, prefix+" center -      fit zeropoint, slope: ",lfit
;printf, 1, prefix+" center -      fit zeropoint, slope: ",lfit
printf, 1, format='(a8," centerfit zerop/slope ",2(f9.4," "))', prefix, lfit[0], lfit[1]


oplot, [a,b], [yl1,yl2], psym=0
plot, xxc, yyc, psym=3, $
        xtitle="true - average line center", $
        ytitle="corr. reconstr. - true line center", $
        xrange=[a,b], yrange=[a,b]
print, prefix+" corr.center - fit zeropoint, slope: ",lfitc
;printf, 1, prefix+" corr.center - fit zeropoint, slope: ",lfitc
printf, 1, format='(a8," c.centfit zerop/slope ",2(f9.4," "))', prefix, lfitc[0], lfitc[1]

close, 1

oplot, [a,b], [ylc1,ylc2], psym=0


; plot for ps file

; plot for line center trends
!p.thick=3
!p.charsize=1.5
set_plot, 'ps'
device, /encapsulated, file=prefix+'trend.eps', /landscape
plot, xx, yy, psym=3, $
        xtitle="true - average line center", $
        ytitle="reconstr. - true line center", $
        xrange=[a,b], yrange=[a,b], $
	position=[.25,.2,.9,.9]
oplot, [a,b], [yl1,yl2], psym=0
!p.charsize=1.5
;xyouts, [a+.3,a+.3], [b-.4,b-.8], ["zero point: "+strtrim(string(lfit[0]),2),"slope:     "+strtrim(string(lfit[1]),2)]
xyouts, a+.3, b-.4, "zero point: "+strtrim(string(lfit[0]),2)+", slope: "+strtrim(string(lfit[1]),2)
device, /close
set_plot, 'x'

; plot for corrected line center trends
!p.thick=3
!p.charsize=1.5
set_plot, 'ps'
device, /encapsulated, file=prefix+'trend_c.eps', /landscape
plot, xxc, yyc, psym=3, $
        xtitle="true - average line center", $
        ytitle="corr. reconstr. - true line center", $
        xrange=[a,b], yrange=[a,b], $
        position=[.25,.2,.9,.9]
oplot, [a,b], [ylc1,ylc2], psym=0
!p.charsize=1.5
xyouts, a+.3, b-.4, "zero point: "+strtrim(string(lfitc[0]),2)+", slope: "+strtrim(string(lfitc[1]),2)
device, /close
set_plot, 'x'


; plot for line width trends
lfit = linfit(xxw,yyw)
yl1=lfit[0]+a*lfit[1]
yl2=lfit[0]+b*lfit[1]
!p.thick=4.
!x.thick=3
!y.thick=3
!p.charsize=1.5
set_plot, 'ps'
device, /encapsulated, file=prefix+'trendw.eps', /color, /landscape
plot, xxw, yyw, psym=3, $
        xtitle="true - average line width", $
        ytitle="reconstr. - true line width", $
        xrange=[a,b], yrange=[a,b], $
        position=[.25,.2,.9,.9]
!p.charsize=1.5
;xyouts, a+.3, b-.4, "zero point: "+strtrim(string(lfit[0]),2)+", slope: "+strtrim(string(lfit[1]),2)
device, /close
set_plot, 'x'

end
