@/usr/local/rsi/idl_5.5/lib/gaussfit.pro
pro prepgraphics, cubename, prefix

; restore the original and reconstructed cube as saved by sim_deconv procedure
cubesav=prefix+'cube.sav'
bcubesav=prefix+'backcube.sav'
restore, cubesav	; results in array 'cube' holding the original data cube
restore, bcubesav	; results in array 'backcube' holding the reconstructed data cube

dim=size(cube)
nwave = dim[1]*1.

; parameters for line center correction factor (to be updated)
; last update 07/11/03 (up to r39_)
corr_zero  = -0.003758
corr_slope = -0.380068

; read in the threshold value in intensity ('nogood') below which a profile is considered to 
; be too weak or not present, and dispersion ('disp'), and rest wavelength ('lambda0')
tmp = get_cube(cubename, "parameters")
nogood = tmp[0]
disp = tmp[1]
lambda0 = tmp[2]

; define arrays				; will hold:
width=fltarr(dim[2]*dim[3])		; line widths
bwidth=fltarr(dim[2]*dim[3])		; reprodocued widths
cent=width				; centers
bcent=width				; reproduced centers
bcentc=bcent				; corrected reproduced centers
diffw=fltarr(dim[2]*dim[3])		; diff in widths
diffc=diffw				; diff in centers
diffcc=diffc				; diff in corrected centers
widthim = fltarr(dim[2],dim[3])		; width image
widthbackim = fltarr(dim[2],dim[3])	; reproduced width image
centim=widthim				; center image
centbackim=centim			; reproduced center image
centbackimc=centim			; reproduced corrected center image
intim=widthim				; total intensity image
intbackim=intim				; repoduced total intensity image

; retrieve average line parameters per slice from file *lineparameters_av.dat 
; as produced by sim_deconv 
n = nlines(prefix+"lineparameters_av.dat")
sl=fltarr(n)	; slice number
p1=fltarr(n)	; padding lower part
p2=fltarr(n)	; padding upper part
lc=fltarr(n)	; line center in pixels
lw=fltarr(n)	; line width in pixels
openr, 1, prefix+"lineparameters_av.dat"
i=0
while not eof(1) do begin
        readf, 1, x1,x2,x3,x4,x5
        sl[i] = x1              ; slice number
        p1[i] = x2              ; padd_1 (padding lower part)
        p2[i] = x3              ; padd_2 (padding upper part)
        lc[i] = x4-x2           ; average line center of slice
        lw[i] = x5              ; average line width of slice
        i=i+1
endwhile
close, 1

; open a file to keep line parameters
openw, 1, prefix+'lineparameters.dat'
openw, 2, prefix+'lineparameters_c.dat'	; for corrected line centers

; double loop over x,y plane
for i=0,dim[2]-1 do begin
for j=0,dim[3]-1 do begin
	ix = i*dim[3]+j				; index for histogram data array
	prof = reform(cube[*,i,j])		; original profile at i,j
	bprof = reform(backcube[*,i,j])		; reproduced profile at i,j
	origintens = total(prof)		; tot. line intensity, original
	backintens = total(bprof)		; tot. line intensity, reprod.
	intim[i,j]=origintens
	intbackim[i,j]=backintens

	if (origintens lt nogood) or (backintens lt nogood) then begin
		; mask out pixels for which profile is not defined
		width[ix]=0 & bwidth[ix]=0 & diffw[ix]=-99999.
		cent[ix]=0 & bcent[ix]=0 & diffc[ix]=-99999.
	endif else begin
		; line parameters for this profile, original and reconstructed
		gfit = gaussfit(findgen(nwave), prof, params, nterms=3)
		bgfit = gaussfit(findgen(nwave), bprof, bparams, nterms=3)
		; calculate corrected line center
		bcentc[ix]=(bparams[1]+corr_slope*lc[j]-corr_zero)/$
			(corr_slope+1)
		; print out center [1] and width [2] 
		printf, 1, i,j,params[1],params[2],bparams[1],bparams[2]
		printf, 2, i,j,params[1],params[2],bcentc[ix],bparams[2]
		; put the center/width values and diffs into the histo arrays
		width[ix] = params[2]		; line width at i,j of original image
		bwidth[ix] = bparams[2]		; line width at i,j of backprojected image
		cent[ix] = params[1]		; line center at i,j of orig.image
                bcent[ix] = bparams[1]		; line center at i,j of backproj. im.
		diffw[ix]=bwidth[ix]-width[ix]	; diff in width
		diffc[ix]=bcent[ix]-cent[ix]	; diff in center
		diffcc[ix]=bcentc[ix]-cent[ix]  ; diff in corrected center
	endelse
	; put the center and width values and diffs also in the image arrays
	widthim[i,j]=width[ix]		; image of original widths
	widthbackim[i,j]=bwidth[ix]	; image of reconstructed widths
	centim[i,j]=cent[ix]		; image of original line centers
	centbackim[i,j]=bcent[ix]	; image of reconstructed line centers
	centbackimc[i,j]=bcentc[ix]	; image of reconstr. corrected line c.
endfor
endfor
close, 1
close, 2


; remove those values from histogram array where profile wasn't defined
; line width histogram:
x9w=where((diffw ne -99999.) and (diffw ne 0.0))
x=diffw[x9w] & diffw=x
; line center histogram:
x9c=where((diffc ne -99999.) and (diffc ne 0.0))
x=diffc[x9c] & diffc=x
; corrected line center histogram:
x9c=where((diffcc ne -99999.) and (diffcc ne 0.0))
x=diffcc[x9c] & diffcc=x


;transformations to km/s for line center
;tickmarks for km/s
dvticks=[-60.,-50.,-40.,-30.,-20.,-10,0.,10.,20.,30.,40.,50.,60.]
;annotations
dvan=['-60','-50','-40','-30','-20','-10','','10','20','30','40','50','60']
tr=disp*300000./lambda0
xdvticks=dvticks/tr         ; convert km/s to pixel value


; calculate average values, standard deviations, and fwhm, also to be kept in logfile
openu, 1, 'LOGFILE', /append
; line center statistics:
momc=moment(diffc) 
fwhm_c=2.35482*sqrt(momc[1])
fwhm_c_kmps = fwhm_c*tr
aver_c = momc[0]
aver_c_kmps = aver_c*tr
print, prefix+" centerr:  min/max/av/fwhm:  ", min(diffc), max(diffc),aver_c,fwhm_c,fwhm_c_kmps
printf, 1, format='(a8," center min/max/av/fwhm ",4(f9.4," "))', $
        prefix, tr*min(diffc), tr*max(diffc),aver_c_kmps,fwhm_c_kmps
; corrected line center statistics:
momcc=moment(diffcc) 
fwhm_cc=2.35482*sqrt(momcc[1])
fwhm_cc_kmps = fwhm_cc*tr
aver_cc = momcc[0]
aver_cc_kmps = aver_cc*tr
print, prefix+" corcent:  min/max/av/fwhm:  ", min(diffcc), max(diffcc), aver_cc,fwhm_cc,fwhm_cc_kmps
printf, 1, format='(a8," corr.c min/max/av/fwhm ",4(f9.4," "))', $
        prefix, tr*min(diffcc), tr*max(diffcc),aver_cc_kmps,fwhm_cc_kmps
; line width statistics:
momw=moment(diffw) 
fwhm_w=2.35482*sqrt(momw[1])
aver_w = momw[0]
print, prefix+" widtherr: min/max/av/fwhm:  ", min(diffw), max(diffw),aver_w,fwhm_w
printf, 1, format='(a8," width  min/max/av/fwhm ",4(f9.4," "))', $
        prefix,min(diffw), max(diffw),aver_w,fwhm_w
close, 1


; save arrays for future use (i.e. in graphics programms) in a structure
result = {	  centhisto_orig:cent, widthhisto_orig:width, $
		  centhisto_reconst:bcent, widthhisto_reconst:bwidth, $
		  centimage_orig:centim, widthimage_orig:widthim, $
		  centimage_reconst:centbackim, widthimage_reconst:widthbackim, $
		  centimagediff:diffc, widthimagediff:diffw, $
		  intensityimage_orig:intim, intensityimage_reconst:intbackim, $
		  centhisto_reconst_corr:bcentc, $
		  centimage_reconst_corr:centbackimc, $ 
		  centimagediff_corr:diffcc, $
		  fwhm_center:fwhm_c, fwhm_center_kmps:fwhm_c_kmps, $
		  fwhm_center_c:fwhm_cc, fwhm_center_c_kmps:fwhm_cc_kmps, $
		  fwhm_width:fwhm_w, $
		  aver_center:aver_c, aver_center_kmps:aver_c_kmps, $
		  aver_center_c:aver_cc, aver_center_c_kmps:aver_cc_kmps, $
		  aver_width:aver_w, $
		  dispersion:disp, lambda0:lambda0}
		  
		  
; ...and write this to a file
filename = prefix+"results.sav"
save, filename=filename, result

end
